@@ -100,7 +100,7 @@ class PdfPredictor():
                     yield {
                         "name": lastPartName,
                         "partNumber": lastPartNumber,
-                        "instruments": instruments,
+                        "instruments": lastInstruments,
                         "fromPage": lastPartNamePage,
                         "toPage": i if j == 0 else i+1
                     }
